/***
 This demo shows you how to use Deadron's PathFinding library.
 When you click on a spot, your mob will move there, avoiding
 all obstacles.

 For convenience this demo uses the EventLoop library so that
 the mob's base_EventCycle() proc will be called each tick.
 You don't have to use that for the PathFinding though.
***/
#include <deadron/pathfinding>
#include <deadron/eventloop>
#include "PathFindingDemo.dmp"


client
	Click(atom/movable/object, location)
		// When the player clicks on something, this client.Click() function is called.
		// object is the thing they clicked on, location is the turf or the name of the
		// statpanel where the click occurred.

		// Set the player's destination to what they clicked.
		mob.destination = object
		return ..()


mob
	icon = 'nurse.dmi'

	var/tmp
		destination
		next_walk_time			// When is the next time for us to walk?
		walking_delay = 10		// How long between movement?
		movement_percent = 50	// What percentage of the time should it move?

	Login()
		src << "<H2>Click any spot to move there.</H2>"
		src << "<H2>The amazing PathFinding library will avoid all obstacles.</H2>"
		return ..()

	base_EventCycle()
		// This gets called once each tick.

		if (next_walk_time <= world.time)
			// It's time to walk if we clicked on something.
			if (destination)
				var/reached_dest = base_StepTowards(destination)
				if (reached_dest)
					// We're there!
					src << "Reached destination!"
					destination = null

			// Set the next walk time.
			next_walk_time = world.time + walking_delay
		return



mob/npc
	icon = 'keystone.dmi'


turf
	icon = 'floorgreen.dmi'
